//! \file phys_data.c
//! This file contains physical data for solar system data.
//==============================================================================
// AEPHEM - an astronomical ephemeris and reduction library.
// Copyright 2008 Adam Hincks.
//
// This file is part of AEPHEM.
//
// AEPHEM is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// AEPHEM is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with AEPHEM.  If not, see <http://www.gnu.org/licenses/>.
//==============================================================================

#include "aephem.h"

//! Physical parameters for the Sun.
struct ae_physical_t ae_phys_sun = {
  696000,
  696000,
  696000,
  0,
  0,
  0,
  286.13, 0, 0, NULL,
  63.87, 0, 0, NULL,
  84.10, 14.1844000, 0, NULL
};

//! Physical parameters for Mercury:  sine terms for w (M1 through M5).
const double ae_phys_mercury_w_sin[] = {
    0.00993822, 174.791086, 4.092335, AE_PHYSICAL_USE_D,
   -0.00104581, 349.582171, 8.184670, AE_PHYSICAL_USE_D,
   -0.00010280, 164.373257, 12.277005, AE_PHYSICAL_USE_D,
   -0.00002364, 339.164343, 16.369340, AE_PHYSICAL_USE_D,
   -0.00000532, 153.955429, 20.461675, AE_PHYSICAL_USE_D
};

//! Physical parameters for Mercury.
const struct ae_physical_t ae_phys_mercury = {
  2439.7,
  2439.7,
  2439.7,
  1.0,
  4.6,
  2.5,
  281.01, -0.0328, 0, NULL,
  61.45, -0.0049, 0, NULL,
  329.5469, 6.1385025, 5, ae_phys_mercury_w_sin
};

//! Physical parameters for Venus.
struct ae_physical_t ae_phys_venus = {
  6051.8,
  6051.8,
  6051.8,
  1,
  11,
  2,
  272.76, 0, 0, NULL,
  67.16, 0, 0, NULL,
  160.2, -1.4813688, 0, NULL
};

//! Physical parameters for Earth.
struct ae_physical_t ae_phys_earth = {
  6371.00,
  6378.14,
  6356.75,
  3.57,
  8.85,
  11.52,
  0.00, -0.641, 0, NULL,
  90.00, -0.557, 0, NULL,
  190.147, 360.9856235, 0, NULL
};

//! Physical parameters for Mars.
struct ae_physical_t ae_phys_mars = {
  3389.50,
  3396.19,
  3376.20,
  3.0,
  22.64,
  7.55,
  317.68143, -0.1061, 0, NULL,
  52.88650, -0.0609, 0, NULL,
  176.630, 350.89198226, 0, NULL
};

//! Physical parameters for Jupiter:  sine terms for ra (Ja through Je).
const double ae_phys_jupiter_sincos[] = {
    0.000117,  99.360714, 4850.4046,  AE_PHYSICAL_USE_T,
    0.000938, 175.895369, 1191.9605,  AE_PHYSICAL_USE_T,
    0.001432, 300.323162,  262.5475,  AE_PHYSICAL_USE_T,
    0.000030, 114.012305, 6070.2476,  AE_PHYSICAL_USE_T,
    0.002150,  49.511251,   64.3000,  AE_PHYSICAL_USE_T
};

//! Physical parameters for Jupiter.
struct ae_physical_t ae_phys_jupiter = {
  69911,
  71492,
  66854,
  62.1,
  31,
  102,
  268.056595, -0.006499, 5, ae_phys_jupiter_sincos,
  64.495303, 0.002413, 5, ae_phys_jupiter_sincos,
  284.95, 870.5360000, 0, NULL
};

//! Physical parameters for Saturn.
struct ae_physical_t ae_phys_saturn = {
  58232,
  60268,
  54364,
  102.9,
  8,
  205,
  40.589, -0.036, 0, NULL,
  83.537, -0.004, 0, NULL,
  38.90, 810.7939024, 0, NULL
};

//! Physical parameters for Uranus.
struct ae_physical_t ae_phys_uranus = {
  25362,
  25559,
  24973,
  16.8,
  28,
  0,
  257.311, 0, 0, NULL,
  -15.175, 0, 0, NULL,
  203.81, -501.1600928, 0, NULL
};

//! Physical parameters for Neptune:  sine term for ra.
const double ae_phys_neptune_ra_sin[] = {
  0.70, 357.85, 52.316, AE_PHYSICAL_USE_T
};

//! Physical parameters for Neptune:  cosine term for ra.
const double ae_phys_neptune_dec_cos[] = {
  -0.51, 357.85, 52.316, AE_PHYSICAL_USE_T
};

//! Physical parameters for Neptune:  sine term for w.
const double ae_phys_neptune_w_sin[] = {
  -0.48, 357.85, 52.316, AE_PHYSICAL_USE_T
};

//! Physical parameters for Neptune.
struct ae_physical_t ae_phys_neptune = {
  24622,
  24764,
  24341,
  8,
  14,
  0,
  299.36, 0.0, 1, ae_phys_neptune_ra_sin,
  43.46, 0.0, 1, ae_phys_neptune_dec_cos,
  253.18, 536.3128492, 1, ae_phys_neptune_w_sin
};

//! Physical parameters for Pluto
struct ae_physical_t ae_phys_pluto = {
  1195,
  1195,
  1195,
  0,
  0,
  0,
  313.02, 0, 0, NULL,
  9.09, 0, 0, NULL,
  236.77, -56.3623195, 0, NULL
//  132.993, 0, 0, NULL,
//  -6.163, 0, 0, NULL,
//  237.305, 56.3625225, 0, NULL
};
